--- layout: default title: Simditor id: demo ---
<p>Simditor is a browser-based WYSIWYG text editor. </p><p>It is used by <a href="http://tower.im">Tower</a> -- a popular project management web application. </p><p>Supported Browsers: IE10+、Chrome、Firefox、Safari.</p> <ul> <li><a href="https://github.com/mycolorway/simditor/releases" target="_blank" class="">Download Zip</a></li> <li>Install with npm: $ npm install simditor</li> </ul>